% FDEMtools3
%   G.P. Deidda, P. Díaz de Alba, F. Pes, and G. Rodriguez
%   University of Cagliari, Italy
%   University of Salerno, Fisciano (Italy)
%
% Forward Model Routines
%   aconduct         - compute the apparent conductivity
%   hratio           - compute the ratio H_S/H_P, i.e., the device readings
%   inphase          - compute the in-phase (real) component of H_S/H_P
%   quadracomp       - compute the quadrature (complex) component of H_S/H_P
%   reflfact         - compute the reflection factor R(lambda)
%
% Computational Routines
%   emsolvenlsig     - reconstruct the electrical conductivity
%   emsolvenlmu      - reconstruct the magnetic permeability
%   tsvdnewt         - Gauss-Newton method regularized by T(G)SVD
%   jack             - approximate the Jacobian matrix by finite differences
%   hankelpts        - quadrature nodes for Hankel transform
%   hankelwts        - quadrature weights for Hankel transform
%   FDEM             - general graphical user interface (GUI) 
%   FDEMforward	     - GUI for forward modelling
%   FDEMinversion    - GUI for data inversion
%
% Test scripts
%   driverforward    - test program for analysing the forward model
%   driver           - test program for the inversion problem
%   driver2D         - test program for 2D inversion 
%   drawfigures      - draws figures reported in Section 5 of the paper
%
% Auxiliary Routines
%   addnoise         - add noise to data
%   chooseparam      - define default parameters and test functions 
%   chooseparambis   - define default parameters
%   cumulativeresp   - compute the cumulative response
%   fdemcomp         - main code for the inversion algorithm
%   fdemdoi          - compute the depth of investigation (DOI)
%   fdemplot         - plot the reconstr. solution and, if avail., the exact one
%   fdemprint        - print information about the whole process
%   fdemsimp         - compute an integral by Simpson's rule
%   forwardcomp      - main code for the forward algorithm
%   mgsreg           - compute the minimum gradient regularization matrix
%   morozov          - choose regularization parameter by discrepancy principle
%   plotcumulative   - display cumulative response
%   plotforward      - display intermediate results during forward modeling
%   plotresults      - display intermediate results during inversion
%   plotsensfunc     - display the sensitivity functions
%   quasihybrid      - choose regularization parameter by quasi-hybrid method
%   skindepth        - compute the skin depth
%   sensitivityfunc  - compute the sensitivity functions
%   
% Auxiliary files
%   FDEMdevices      - GUI for managing the device database
%   dev.mat          - data file containing the device database
%   information.pdf  - file displayed by FDEMinversion and FDEMforward
%   FDEMfwoutput.mat - data file produced by FDEMforward
%   FDEMoutput.mat   - data file produced by FDEMinversion

