FDEMtools3
============

---

AUTHORS
-------

- Gian Piero Deidda, Caterina Fenu, Gabriele Lovicu, and Giuseppe Rodriguez,
       University of Cagliari, Italy
- Patricia Daz de Alba,
       University of Salerno, Italy
- Federica Pes,
       University of Pisa, Italy

> Email: gpdeidda@unica.it, pdiazdealba@unisa.it, kate.fenu@unica.it,
      federica.pes@dcci.unipi.it, lovicu.gabriele.gl@gmail.com,
      rodriguez@unica.it

---

REFERENCES
----------

_G. P. Deidda, P. Daz de Alba, F. Pes, and G. Rodriguez_
**Forward electromagnetic induction modelling in a multilayered half-space: An
open-source software tool.**
Submitted.
[link](https://doi.org/10.3390/rs15071772/)

_G. P. Deidda, P. Daz de Alba, C. Fenu, G. Lovicu, and G. Rodriguez_
**FDEMtools: a MATLAB package for FDEM data inversion**
Numerical Algorithms, 84:1313-1327, 2020.
[link](https://doi.org/10.1007/s11075-019-00843-2)

---

DESCRIPTION
-----------

This package provides a set of Matlab functions for frequency domain
electromagnetic (FDEM) induction data processing in Applied Geophysics.

The forward model consists of computing the data measured by a FDEM induction
device, when the distribution of electrical conductivity and the magnetic
permeability in the subsoil are known.

Starting from electromagnetic data collected by a ground conductivity meter,
we reconstruct either the electrical conductivity or the magnetic permeability
of the soil with respect to depth by a regularized Gauss-Newton method.
The inversion algorithm is based on the low-rank approximation of the Jacobian
of the nonlinear model, which depends both on a relaxation parameter and a
regularization parameter, chosen by automatic procedures.

The package includes a graphical user interface (FDEMforward) for the
forward model and another graphical user interface (FDEMinversion) for the
inversion algorithm.

FDEMforward allows the user to experiment with different configurations
and strategies in order to compute the apparent conductivity of the soil,
compare the results, and draw conclusions on which kind of configuration
devices is more appropriate when a specific area is studied.

FDEMinversion allows the user to experiment with both synthetic and experimental
data sets in the inversion of FDEMdata with different regularization
strategies, in order to compare them and draw conclusions.

See the help page for each function, for the calling syntax.

Software revision date: V3.0, March 2023

Software language: Matlab 9.12 (R2022a)

---

DISCLAIMER
----------
The authors are not responsible for any problems the code may cause; see the
file License.md for details.

---

INSTALLATION
------------

When the archive file containing the package is uncompressed, it creates a
directory named FDEMtools3. In order to use the package outside this directory,
its name must be added to the Matlab search path, either by the "addpath"
command, or using the menus available in the graphical user interface.

Some of the package functions require the toolbox Regularization Tools
described in the paper

P.C. Hansen. Regularization Tools: version 4.0 for Matlab 7.3,
Numerical Algorithms, 46 (2007), pp. 189-194; see 
[link](http://www2.imm.dtu.dk/~pcha/Regutools/)
for information.

This toolbox can be downloaded at the website
[link](https://it.mathworks.com/matlabcentral/fileexchange/52-regtools)
and should be installed and added to the search Matlab path, for the package to
work properly.

The Matlab pdf reader should be configured.

---

PACKAGE USE
-----------

Once the package is correctly configured, the Test scripts (see below) should
run without errors.

---

PACKAGE STRUCTURE
-----------------

The main FDEMtools3 directory contains the following files:

Forward Model Routines

- aconduct         : compute the apparent conductivity
- hratio           : compute the ratio H_S/H_P, i.e., the device readings
- inphase          : compute the in-phase (real) component of H_S/H_P
- quadracomp       : compute the quadrature (complex) component of H_S/H_P
- reflfact         : compute the reflection factor R(lambda)

Computational Routines

- emsolvenlsig     : reconstruct the electrical conductivity
- emsolvenlmu      : reconstruct the magnetic permeability
- tsvdnewt         : Gauss-Newton method regularized by T(G)SVD
- jack             : approximate the Jacobian matrix by finite differences
- hankelpts        : quadrature nodes for Hankel transform
- hankelwts        : quadrature weights for Hankel transform
- FDEM             : general graphical user interface (GUI)
- FDEMforward	   : GUI for forward modelling
- FDEMinversion    : GUI for data inversion

Test scripts

- driverforward    : test program for analysing the forward model
- driver           : test program for the inversion problem
- driver2D         : test program for 2D inversion
- drawfigures      : draws figures reported in Section 5 of the paper

Auxiliary Routines

- addnoise         : add noise to data
- chooseparam      : define default parameters and test functions
- chooseparambis   : define default parameters
- cumulativeresp   : compute the cumulative response
- fdemcomp         : main code for the inversion algorithm
- fdemdoi          : compute the depth of investigation (DOI)
- fdemplot         : plot the reconstr. solution and, if avail., the exact one
- fdemprint        : print information about the whole process
- fdemsimp         : compute an integral by Simpson's rule
- forwardcomp      : main code for the forward algorithm
- mgsreg           : compute the minimum gradient regularization matrix
- morozov          : choose regularization parameter by discrepancy principle
- plotcumulative   : display cumulative response
- plotforward      : display intermediate results during forward modeling
- plotresults      : display intermediate results during inversion
- plotsensfunc     : display the sensitivity functions
- quasihybrid      : choose regularization parameter by quasi-hybrid method
- skindepth        : compute the skin depth
- sensitivityfunc  : compute the sensitivity functions

Auxiliary files

- FDEMdevices      : GUI for managing the device database
- dev.mat          : data file containing the device database
- information.pdf  : file displayed by FDEMinversion and FDEMforward
- FDEMfwoutput.mat : data file produced by FDEMforward
- FDEMoutput.mat   : data file produced by FDEMinversion

---

PACKAGE UPDATES
---------------

FDEMtools3 updates will be available at the web page
[link](http://bugs.unica.it/cana/software/)

