function btilde = addnoise(rhs,sigma,noisetype,scalrhs)
%ADDNOISE add noise to data
%   btilde = addnoise(rhs,sigma,noisetype,scalrhs)
%   where
%      rhs   	 - initial data 
%      sigma     - noise level
%      noisetype - kind of noise (white, relative or absolute)
%      scalrhs 	 - vector to be used for scaling (defaults to rhs)
%   and
%      btilde    - noisy data

%   G. Rodriguez, University of Cagliari, Italy
%
%   Last revised March 19, 2023

if nargin<4, scalrhs = rhs; end

n1 = size(rhs,1);

if isreal(rhs)
	noise = randn(n1,1);
else
	noise = randn(n1,1) + 1i*randn(n1,1);
end

if strncmp(noisetype(1:3),'whi',3)
	btilde = rhs + sigma * noise;
elseif strncmp(noisetype(1:3),'rel',3)
	btilde = rhs + sigma * norm(scalrhs) * noise/sqrt(n1); % sqrt(n)=norm(noise)
elseif strncmp(noisetype(1:3),'sca',3)
	btilde = rhs + sigma * abs(scalrhs) .* noise;
else
	error( 'Noise type unknown.')
end

