% converter_inputmodel.m
%
% convert an excel data file with the input model into the data structure used by FDEMtools

% read vertical data from excel file explorer.xlsx (sheet 1) 
[num txt raw] = xlsread('inputmodel.xlsx',1);

data = num; % data for the input model

n = size(data,1);		% number of measurements
z = data(:,2);			% depth vector
sigmamodel = data(:,3);		% conductivity input model
mu0 = pi*4e-7;			% magnetic permeability of free space
mumodel = mu0.*data(:,4);	% permeability input model

if any(mumodel < mu0/10)
	warning('Watch out! This converter reads relative permeability values.')
end

% create data structure
FDEMinputmodel.name = 'prova';
FDEMinputmodel.z = z;
FDEMinputmodel.sigmamodel = sigmamodel;
FDEMinputmodel.mumodel = mumodel;
FDEMinputmodel.type = 'real';
FDEMinputmodel.info = 'input model for EM data inversion';
FDEMinputmodel

save(FDEMinputmodel.name,'FDEMinputmodel')

