% DRAWFIGURES test program
% this script draws figures reported in Section 5 of the paper
%
% G.P. Deidda, P. Díaz de Alba, F. Pes, and G. Rodriguez
% Forward electromagnetic induction modelling in a multilayered half-space: 
% An open-source software tool.
% Remote Sensing, 2023.
%
% the device can be selected at lines 29-36
% the earth model can be selected at line 54

% Last revised March 5, 2023

%
% Choose model type
%
%modeltype = 5;		% 1 aconduct, 2 quadracomp, 3 inphase, 4 complexquad, 5 complexacon
geninputdata = 1;	% 0 load input file, 1 generate data from function
graphindnum = 0;	% 0 no induction number graph, 1 induction number graph
graphskindepth = 0;	% 0 no skin depth graph, 1 skin depth graph
%graphtype = 3;		% 1 graph w.r.t R, 2 graph w.r.t f, 3 graph w.r.t h
sensfunc = 1;		% 0 no sensitivity functions, 1 sensitivity functions
cumresp = 0;		% 0 no cumulative response, 1 cumulative response
%pos = 'northwest';	% legend position
pos = 'northeast';	% legend position
%pos = 'southwest';	% legend position
%pos = 'southeast';	% legend position

% device: uncomment one
%
%	DUALEM 21H
R = [0.5 1 2]'; freq = 9000; HVorient = 'vp'; graphtype = 3; modeltype = 5;
%	Explorer
%R = [1.48 2.82 4.49]'; freq = 10000; HVorient = 'vh'; graphtype = 3; modeltype = 5;
%	Geophex GEM-2
%R = 1.66; freq = [1275, 4250, 12525, 28725, 54150, 82150]; HVorient = 'vertical'; graphtype = 2; modeltype = 4;

%
% General configuration
%
chooseparam				% Initialize parameters
asigma = 0.2;
bsigma = 1;
z0sigma = 1;
minsigma = 1.9;
maxsigma = 0.6;
amu = mu0;
bmu = mu0;
z0mu = 1;
minmu = 0.6;
maxmu = 1.9;

% earth model: choose one
model = 1;
switch model
case 1		% first earth model
	funsigma = @(z) 0.05.*(z<=1.5) + 0.001.*(z>1.5).*(z<2.5) + 0.01*(z>=2.5);
	funmu = @(z) mu0*(1.*(z<=1.5) + 1.01.*(z>1.5).*(z<2.5) + 1.005*(z>=2.5));
case 2		% second earth model
	funsigma = @(z) 0.05.*(z<=1.5) + 2.*(z>1.5).*(z<2.5) + 0.01*(z>=2.5);
	funmu = @(z) mu0*(1.*(z<=1.5) + 1.01.*(z>1.5).*(z<2.5) + 1.005*(z>=2.5));
end

%
% Discretization
%
n = 61;				% Number of layers
lastz = 6;			% Maximum depth
m = 1;				% Number of measurement heights over the ground
hmin = 0.1;
hmax = 0.9;
h = linspace(hmin,hmax,m)';	% Heights discretization
z = linspace(0,lastz,n)';	% Layers discretization
% Intercoil distance vector for graphical analysis of response
rmin = 1; rmax = 5;
% Frequency vector for graphical analysis of response 
fmin = 1; fmax = 1e5;
% Height vector for graphical analysis of response
hhmin = 0.01; hhmax = 2;

% adjust axis limits
rmin = min([rmin;R(:)]); rmax = max([rmax;R(:)]);
fmin = min([fmin;freq(:)]); fmax = max([fmax;freq(:)]);
hhmin = min([hhmin;h(:)]); hhmax = max([hhmax;h(:)]);

switch graphtype	% 1 linear scale, 0 log scale
case {1,3}
	linscale = 1;
otherwise
	linscale = 0;
end

profgraph = 1;
legendavail = 1;
fileavail = 0;
calledbyapp = 0;
textarea = [];
fff = 20;		% first forward figure

forwardcomp

%
% Saving data
%
FDEMdata.name = FDEMforward.name;
FDEMdata.R = R;
FDEMdata.freq = freq;
FDEMdata.height = h;
FDEMdata.vdata = vdata;
FDEMdata.hdata = hdata;
FDEMdata.pdata = pdata;
FDEMdata.orient = HVorient;
FDEMdata.coors = [];
FDEMdata.type = type;
FDEMdata.device = 'FDEMforward';
FDEMdata.info = 'FDEMforward data simulating XXX device';

save FDEMfwoutput FDEMdata

disp('The results have been stored in the variable FDEMdata and saved in FDEMfwoutput')

