% DRIVER test program

% G.P. Deidda, P. Díaz de Alba, C. Fenu, and G. Rodriguez
% University of Cagliari, Italy
%
% Last revised January 26, 2023

%
% Choose what to compute, model type, and noise type
%
whattocomp = 1;		% 1 for sigma (el. cond.), 2 for mu (mag. perm.)
modeltype = 2;		% 1 aconduct, 2 quadracomp, 3 inphase, 4 complex
samenoise = 0;		% 1 uses the same noise at each run, 0 changes it
syntheticdata = 1;	% 1 for synthetic data, 0 for experimental data
showpcolor = 1;		% 1 for pcolor plot for multicolumn experimental data

%
% General configuration
%
chooseparam		% Initialize parameters
chooseparambis
show = 10;		% Show information during computation
invertall = 1;		% Set to 1 to process all columns in loaded data
coltoinvert = 1;	% Index of column to be inverted (invertall=0)
averagecols = 0;	% 1 to compute the mean of all columns in loaded data
forceorient = 0;	% Force vert (1), horiz (2), perp (3) orient in loaded data
beta = 1;		% weight for in-phase component (complex signal)
mnflag = 0;		% 0 standard solution, 1-4 for minimal norm solution
usexbar = 0;		% use init vector as a priori estimate for solution

warning('off','Corner:warnings')

%
% Device configuration (R in meters and freq in Hertz)
%
%R = 1; freq = 14600;					% Geonics EM38
%R = 0.98; freq = 10000;				% GF Instruments CMD-1
R = 1.66; freq = [775, 1175, 3925, 9825, 21725, 47025]'; % Geophex GEM-2
%R = 1.66; freq = [1175, 3925, 9825, 21725]';		% Geophex GEM-2
%R = [1.48 2.82 4.49]'; freq = 10000;			% Explorer
%R = [0.32 0.71 1.18]'; freq = 30000;			% Mini Explorer

%
% Discretization
%
n = 60;				% Number of layers
lastz = 3.5;			% Maximum depth
m = 1;				% Number of measurement heights over the ground
lasth = 1;			% Last height
ds = 1e-3;			% Noise level
taudiscr = 1.1;			% Tau for discrepancy
orientation = 'vertical';		% Orientation of device
%orientation = 'horizontal';
%orientation = 'perpendicular';
%orientation = 'vh';
%orientation = 'vp';

z = linspace(0,lastz,n)';	% Layers discretization
d = (lastz/(n-1))*ones(n-1,1);	% Layers width (except last, which is infinite)
h = linspace(lasth/m,lasth,m)';	% Heights discretization
nR = length(R);			% Number of coil pairs
nf = length(freq);		% Number of frequencies
omega = 2*pi*freq;		% Vector of angular frequencies

%
% Signal component to be inverted (functions defined in chooseparam.m)
%
theta = 2;			% Scaling factor for test function 11
switch whattocomp
	case 1
		asigma = 0.2;
		bsigma = 1;
		z0sigma = 1;
		mur = 1;			% Rel. magnetic permeability
		funsigma = @(z) funs{11}(z-z0sigma,bsigma,asigma);		% Test function for sigma
		sigmazero = .5;			% Level of initial solution
		sigmainit = sigmazero*ones(n,1); % Initial solution
		mu = mu0*mur.*ones(n,1);	% Permeability (vector)
	case 2
		asigma = 0.2;
		bsigma = 1;
		z0sigma = 1;
		amu = mu0;
		bmu = mu0;
		z0mu = 1;
		funsigma = @(z) funs{11}(z-z0sigma,bsigma,asigma); % Test function for sigma
		funmu = @(z) funs{11}(z-z0mu,bmu,amu); % Test function for mu
		muzero = 2*mu0;		% Level of initial solution
		muinit = muzero*ones(n,1);	% Initial solution
		sigma = 1*funsigma(z);		% Conductivity (vector)
end

%
% Regularization settings
%
Lind = 2;	% Regularization matrix (0 norm of solution, k kth derivative)
Ltype = 0;	% Type of regularization matrix (0 derivative, 1 MGS)

% MGS regularizer
tauMGS = 1e-8;
epsilon = 1;
sigmam = tauMGS*ones(n-Lind,1);

% Methods for choosing the regularization parameter, choose from:
% 'quasihyb','corner','quasiopt','discrepancy','optimal','noreg'
metk = {'corner','quasiopt'};

%
% Computing the Jacobian
%    0 Newton,
%    1 Broyden
%    2 Recompute every 10 iterations, Broyden update
%    3 Recompute every 10 iterations, no update
%    4 Finite differences
%
metjac = 0;

%
% Store noise generator status
%
if samenoise
	if ~exist('rngstatus')
		fdemprint( 'Noise generator status stored', calledbyapp, textarea)
		rngstatus = rng;
	end
else
	rngstatus = rng;
end

%
% Initialize some variables needed by fdemcomp
%
fileavail = 0;
modelavail = 0;
filmodavail = 0;
calledbyapp = 0;
textarea = [];

fdemcomp	% Calling inversion function

%
% Saving data
%
FDEMresults.solution = SOL;
FDEMresults.model = func;
FDEMresults.z = z;
FDEMresults.parameter_choice = metk{1};
FDEMresults.opts = opts;
FDEMresults.kappa = kappavet;
save FDEMoutput1Dtest FDEMresults

disp('The results have been stored in the variable FDEMresults and saved in FDEMoutput1Dtest')
