% DRIVERFORWARD test program

% G.P. Deidda, P. Díaz de Alba, and G. Rodriguez
% University of Cagliari, Italy
%
% Last revised January 26, 2023

%
% Choose model type
%
modeltype = 1;		% 1 aconduct, 2 quadracomp, 3 inphase, 4 complexquad, 5 complexacon
geninputdata = 1;	% 0 load input file, 1 generate data from function
graphindnum = 0;	% 0 no induction number graph, 1 induction number graph
graphskindepth = 0;	% 0 no skin depth graph, 1 skin depth graph
graphtype = 2;		% 1 graph w.r.t R, 2 graph w.r.t f, 3 graph w.r.t h
sensfunc = 0;		% 0 no sensitivity functions, 1 sensitivity functions
cumresp = 0;		% 0 no cumulative response, 1 cumulative response
%pos = 'northwest';	% legend position
pos = 'northeast';	% legend position
%pos = 'southwest';	% legend position
%pos = 'southeast';	% legend position

%
% Device configuration (R in meters and freq in Hertz)
%
%R = 1; freq = 14600;	% Geonics EM38
%R = 0.98; freq = 10000;	% GF Instruments CMD-1
%R = 3.66; freq = 9800;
R = 1.66; freq = [775, 1175, 3925, 9825, 21725, 47025];  % Geophex GEM-2
%R = 1.66; freq = [1175, 3925, 9825, 21725]; % Geophex GEM-2
%R = [1.48 2.82 4.49]'; freq = 10000;	% Explorer
%R = [0.32 0.71 1.18]'; freq = 30000;	% Mini Explorer
%R = [0.32 0.71 1.18]'; freq = [1175, 3925, 9825, 21725]; % fictious

% coil orientation
HVorient = 'vertical';
%HVorient = 'horizontal';
%HVorient = 'perpendicular';
%HVorient = 'vh';
%HVorient = 'vp'; 

%
% General configuration
%
chooseparam				% Initialize parameters
asigma = 0.2;
bsigma = 1;
z0sigma = 1;
minsigma = 1.9;
maxsigma = 0.6;
amu = mu0;
bmu = mu0;
z0mu = 1;
minmu = 0.6;
maxmu = 1.9;

%funsigma = @(z) ((1/z0sigma).*(bsigma-asigma)*z+bsigma).*(z<=z0sigma) + ((bsigma-asigma)*exp(-(z-z0sigma))+bsigma).*(z>z0sigma);
%funsigma = @(z) minsigma.*(z<=asigma) + maxsigma.*(z>asigma).*(z<bsigma) + minsigma.*(z>=bsigma);
%funsigma = @(z) asigma*exp(-(z-z0sigma).^2)+bsigma;
funsigma = @(z) funs{11}(z-z0sigma,bsigma,asigma);

%funmu = @(z) mu0*(((1/z0mu).*(bmu-amu)*z+bmu).*(z<=z0mu) + ((bmu-amu)*exp(-(z-z0mu))+bmu).*(z>z0mu));
%funmu = @(z) mu0*(minmu.*(z<=amu) + maxmu.*(z>amu).*(z<bmu) + minmu.*(z>=bmu));
%funmu = @(z) mu0*(amu*exp(-(z-z0mu).^2)+bmu);
funmu = @(z) funs{11}(z-z0mu,bmu,amu);

%
% Discretization
%
n = 35;				% Number of layers
lastz = 3.5;			% Maximum depth
m = 1;				% Number of measurement heights over the ground
hmin = 0.1;
hmax = 1;
h = linspace(hmin,hmax,m)';	% Heights discretization
z = linspace(0,lastz,n)';	% Layers discretization
% Intercoil distance vector for graphical analysis of response
rmin = 1; rmax = 5;
% Frequency vector for graphical analysis of response 
fmin = 1; fmax = 1e5;
% Height vector for graphical analysis of response
hhmin = 0.01; hhmax = 2;

% adjust axis limits
rmin = min([rmin;R(:)]); rmax = max([rmax;R(:)]);
fmin = min([fmin;freq(:)]); fmax = max([fmax;freq(:)]);
hhmin = min([hhmin;h(:)]); hhmax = max([hhmax;h(:)]);

switch graphtype	% 1 linear scale, 0 log scale
case {1,3}
	linscale = 1;
otherwise
	linscale = 0;
end

profgraph = 1;
legendavail = 1;
fileavail = 0;
calledbyapp = 0;
textarea = [];
fff = 20;		% first forward figure

forwardcomp

%
% Saving data
%
FDEMdata.name = FDEMforward.name;
FDEMdata.R = R;
FDEMdata.freq = freq;
FDEMdata.height = h;
FDEMdata.vdata = vdata;
FDEMdata.hdata = hdata;
FDEMdata.pdata = pdata;
FDEMdata.orient = HVorient;
FDEMdata.coors = [];
FDEMdata.type = type;
FDEMdata.device = 'FDEMforward';
FDEMdata.info = 'FDEMforward data simulating XXX device';

save FDEMfwoutput FDEMdata

disp('The results have been stored in the variable FDEMdata and saved in FDEMfwoutput')

