function plotcumulative(fig,CRs,CRm,z,lastz,orientation,xlab,ylab1,ylab2,ylab3,ylab4,legendavail,pos,legendsens,modeltype)
%PLOTCUMULATIVE display cumulative responses
%   plotcumulative(fig,CRs,CRm,z,orientation,xlab,ylab1,ylab2,ylab3,ylab4,legendavail,pos,legendsens,modeltype)
%   where
%		fig		- figure in which make the plot
%		CRs		- Jacobian matrix w.r.t sigma
%		CRm		- Jacobian matrix w.r.t mu
%		z 		- depth vector
%		lastz 		- max z displayed on graphs
%		orientation 	- orientation of the device
%		xlab		- label for the x axis
%		ylab1		- label for the y axis
%		ylab2		- label for the y axis
%		ylab3		- label for the y axis
%		ylab4		- label for the y axis
%		legendavail	- 1 display legend, 0 do not display legend
%		pos		- legend position
%		legendsens	- legend content
%		modeltype	- 1 aconduct, 2 quadracomp, 3 inphase, 
%					4 complexquad, 5 complexacon

%   G.P. Deidda, P. Díaz de Alba, and G. Rodriguez
%   University of Cagliari, Italy
%
%   Last revised January 26, 2023

mdata = size(CRs,1);

if strcmpi(orientation(1:2),'vh')
	figure(fig+40)
	clf
	set(gcf,'NumberTitle', 'off','name',...
		'Cumulative response (electrical conductivity - vertical orientation')
	if modeltype == 4
		subplot(1,2,1)
		plot(z(1:end-1),real(CRs(1:mdata/2,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRs(1:mdata/2,:)))
		grid on
		title('Quadrature component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab2,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	elseif modeltype == 5
		subplot(1,2,1)
		plot(z(1:end-1),real(CRs(1:mdata/2,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRs(1:mdata/2,:)))
		grid on
		title('Apparent conductivity','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab2,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	else
		plot(z(1:end-1),CRs(1:mdata/2,:))
		grid on
		title('Vertical Orientation')
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	end
	figure(fig+41)
	clf
	set(gcf,'NumberTitle', 'off','name',...
		'Cumulative response (electrical conductivity - horizontal orientation)')
	if modeltype == 4
		subplot(1,2,1)
		plot(z(1:end-1),real(CRs(mdata/2+1:end,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRs(mdata/2+1:end,:)))
		grid on
		title('Quadrature component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab2,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	elseif modeltype == 5
		subplot(1,2,1)
		plot(z(1:end-1),real(CRs(mdata/2+1:end,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRs(mdata/2+1:end,:)))
		grid on
		title('Apparent conductivity','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab2,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	else
		plot(z(1:end-1),CRs(mdata/2+1:end,:))
		grid on
		title('Horizontal Orientation')
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	end
	figure(fig+42)
	clf
	set(gcf,'NumberTitle', 'off','name',...
		'Cumulative response (magnetic permeability - vertical orientation')
	if modeltype == 4
		subplot(1,2,1)
		plot(z(1:end-1),real(CRm(1:mdata/2,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRm(1:mdata/2,:)))
		grid on
		title('Quadrature component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab4,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	elseif modeltype == 5
		subplot(1,2,1)
		plot(z(1:end-1),real(CRm(1:mdata/2,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRm(1:mdata/2,:)))
		grid on
		title('Apparent conductivity','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab4,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	else
		plot(z(1:end-1),CRm(1:mdata/2,:))
		grid on
		title('Vertical Orientation')
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	end
	figure(fig+43)
	clf
	set(gcf,'NumberTitle', 'off','name',...
		'Cumulative response (magnetic permeability - horizontal orientation)')
	if modeltype == 4
		subplot(1,2,1)
		plot(z(1:end-1),real(CRm(mdata/2+1:end,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRm(mdata/2+1:end,:)))
		grid on
		title('Quadrature component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab4,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	elseif modeltype == 5
		subplot(1,2,1)
		plot(z(1:end-1),real(CRm(mdata/2+1:end,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRm(mdata/2+1:end,:)))
		grid on
		title('Apparent conductivity','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab4,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	else
		plot(z(1:end-1),CRm(mdata/2+1:end,:))
		grid on
		title('Horizontal Orientation')
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	end
elseif strcmpi(orientation(1:2),'vp')
	figure(fig+40)
	clf
	set(gcf,'NumberTitle', 'off','name',...
		'Cumulative response (electrical conductivity - vertical orientation')
	if modeltype == 4
		subplot(1,2,1)
		plot(z(1:end-1),real(CRs(1:mdata/2,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRs(1:mdata/2,:)))
		grid on
		title('Quadrature component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab2,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	elseif modeltype == 5
		subplot(1,2,1)
		plot(z(1:end-1),real(CRs(1:mdata/2,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRs(1:mdata/2,:)))
		grid on
		title('Apparent conductivity','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab2,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	else
		plot(z(1:end-1),CRs(1:mdata/2,:))
		grid on
		title('Vertical Orientation')
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	end
	figure(fig+41)
	clf
	set(gcf,'NumberTitle', 'off','name',...
		'Cumulative response (electrical conductivity - perpendicular orientation)')
	if modeltype == 4
		subplot(1,2,1)
		plot(z(1:end-1),real(CRs(mdata/2+1:end,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRs(mdata/2+1:end,:)))
		grid on
		title('Quadrature component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab2,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	elseif modeltype == 5
		subplot(1,2,1)
		plot(z(1:end-1),real(CRs(mdata/2+1:end,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRs(mdata/2+1:end,:)))
		grid on
		title('Apparent conductivity','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab2,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	else
		plot(z(1:end-1),CRs(mdata/2+1:end,:))
		grid on
		title('Perpendicular Orientation')
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	end
	figure(fig+42)
	clf
	set(gcf,'NumberTitle', 'off','name',...
		'Cumulative response (magnetic permeability - vertical orientation')
	if modeltype == 4
		subplot(1,2,1)
		plot(z(1:end-1),real(CRm(1:mdata/2,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRm(1:mdata/2,:)))
		grid on
		title('Quadrature component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab4,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	elseif modeltype == 5
		subplot(1,2,1)
		plot(z(1:end-1),real(CRm(1:mdata/2,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRm(1:mdata/2,:)))
		grid on
		title('Apparent conductivity','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab4,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	else
		plot(z(1:end-1),CRm(1:mdata/2,:))
		grid on
		title('Vertical Orientation')
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	end
	figure(fig+43)
	clf
	set(gcf,'NumberTitle', 'off','name',...
		'Cumulative response (magnetic permeability - perpendicular orientation)')
	if modeltype == 4
		subplot(1,2,1)
		plot(z(1:end-1),real(CRm(mdata/2+1:end,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRm(mdata/2+1:end,:)))
		grid on
		title('Quadrature component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab4,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	elseif modeltype == 5
		subplot(1,2,1)
		plot(z(1:end-1),real(CRm(mdata/2+1:end,:)))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRm(mdata/2+1:end,:)))
		grid on
		title('Apparent conductivity','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		ylabel(ylab4,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	else
		plot(z(1:end-1),CRm(mdata/2+1:end,:))
		grid on
		title('Perpendicular Orientation')
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	end
elseif strcmpi(orientation(1:2),'ve')
	figure(fig+40)
	clf
	set(gcf,'NumberTitle', 'off','name','Cumulative response (electrical conductivity - vertical orientation)')
	if modeltype == 4
		subplot(1,2,1)
		plot(z(1:end-1),real(CRs))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRs))
		grid on
		title('Quadrature component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab2,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	elseif modeltype == 5
		subplot(1,2,1)
		plot(z(1:end-1),real(CRs))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRs))
		grid on
		title('Apparent conductivity','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab2,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	else
		plot(z(1:end-1),CRs)
		grid on
		title('Vertical Orientation')
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	end
	figure(fig+41)
	clf
	set(gcf,'NumberTitle', 'off','name','Cumulative response (magnetic permeability - vertical orientation)')
	if modeltype == 4
		subplot(1,2,1)
		plot(z(1:end-1),real(CRm))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRm))
		grid on
		title('Quadrature component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab4,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	elseif modeltype == 5
		subplot(1,2,1)
		plot(z(1:end-1),real(CRm))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRm))
		grid on
		title('Apparent conductivity','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab4,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	else
		plot(z(1:end-1),CRm)
		grid on
		title('Vertical Orientation')
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	end
elseif strcmpi(orientation(1:2),'ho')
	figure(fig+40)
	clf
	set(gcf,'NumberTitle', 'off','name','Cumulative response (electrical conductivity - horizontal orientation)')
	if modeltype == 4
		subplot(1,2,1)
		plot(z(1:end-1),real(CRs))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRs))
		grid on
		title('Quadrature component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab2,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	elseif modeltype == 5
		subplot(1,2,1)
		plot(z(1:end-1),real(CRs))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRs))
		grid on
		title('Apparent conductivity','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab2,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	else
		plot(z(1:end-1),CRs)
		grid on
		title('Horizontal Orientation')
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	end
	figure(fig+41)
	clf
	set(gcf,'NumberTitle', 'off','name','Cumulative response (magnetic permeability - horizontal orientation)')
	if modeltype == 4
		subplot(1,2,1)
		plot(z(1:end-1),real(CRm))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRm))
		grid on
		title('Quadrature component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab4,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	elseif modeltype == 5
		subplot(1,2,1)
		plot(z(1:end-1),real(CRm))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRm))
		grid on
		title('Apparent conductivity','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab4,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	else
		plot(z(1:end-1),CRm)
		grid on
		title('Horizontal Orientation')
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	end
elseif strcmpi(orientation(1:2),'pe')
	figure(fig+40)
	clf
	set(gcf,'NumberTitle', 'off','name','Cumulative response (electrical conductivity - perpendicular orientation)')
	if modeltype == 4
		subplot(1,2,1)
		plot(z(1:end-1),real(CRs))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRs))
		grid on
		title('Quadrature component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab2,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	elseif modeltype == 5
		subplot(1,2,1)
		plot(z(1:end-1),real(CRs))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRs))
		grid on
		title('Apparent conductivity','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab2,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	else
		plot(z(1:end-1),CRs)
		grid on
		title('Perpendicular Orientation')
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab1,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	end
	figure(fig+41)
	clf
	set(gcf,'NumberTitle', 'off','name','Cumulative response (magnetic permeability - perpendicular orientation)')
	if modeltype == 4
		subplot(1,2,1)
		plot(z(1:end-1),real(CRm))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel('Depth (m)','fontsize',11)
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRm))
		grid on
		title('Quadrature component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab4,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	elseif modeltype == 5
		subplot(1,2,1)
		plot(z(1:end-1),real(CRm))
		grid on
		title('In-phase component','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
		subplot(1,2,2)
		plot(z(1:end-1),imag(CRm))
		grid on
		title('Apparent conductivity','fontsize',9)
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab4,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	else
		plot(z(1:end-1),CRm)
		grid on
		title('Perpendicular Orientation')
		if legendavail == 1
			legend(legendsens,'location', pos)
		end
		xlabel(xlab,'fontsize',11)
		ylabel(ylab3,'fontsize',11)
		view([90 90])
		xlim([0 lastz])
	end
end
