function plotforward(fig,data,h,hp,orientation,xlab,ylab1,ylab2,legendCell,legendCellp,linscale,xlong,xlongp,ylong,legendavail,pos,modeltype)
%PLOTFORWARD display results
%   plotforward(fig,data,h,orientation,xlab,ylab1,ylab2,legendCell,linscale,xlong,ylong,legendavail,pos,modeltype)
%   where
%	fig		- figures in which make the plot
%	data		- value of hratio in each layer
%	h		- heights
%	hp		- abscissa axis for the perpendicular orientation
%	orientation	- orientation of the device
%	xlab		- lable for the x axis
%	ylab1		- lable for the y axis
%	ylab2		- lable for the y axis
%	legendCell	- text for the legend
%	legendCellp	- text for the legend for the perpendicular orientation
%	linscale	- 1 linear scale, 0 logaritmic scale for the axis
%	xlong		- ratio, frequency, or height vector
%	xlongp		- ratio, frequency, or height vector for the perpendicular
%			  orientation
%	ylong		- ratio, frequency, or height data vector 
%	legendavail	- 1 show the legend, 0 do not show the legend
%	pos		- legend position
%	modeltype	- 1 aconduct, 2 quadracomp, 3 inphase, 4 complexquad, 
%				5 complexacon

%   G.P. Deidda, P. Díaz de Alba, C. Fenu, and G. Rodriguez
%   University of Cagliari, Italy
%
%   Last revised January 26, 2023

if (nargin<8), islong = 0; else, islong = 1; end
if (nargin<7) || isempty(linscale), linscale = 0; end
if (nargin<6) || isempty(xlab), xlab = ''; end

complexdata = ~isreal(data);
if complexdata, data = [real(data); imag(data)]; end
m = size(data,1);
%form = '*--';
form = '*';
%legloc = 'northwest';

if islong == 1
	complexylong = ~isreal(ylong);
	if complexylong, ylong = [real(ylong); imag(ylong)]; end
	my = size(ylong,1);
end

if strcmpi(orientation(1:2),'vh')
	if complexdata
		figure(fig)
		set(gcf,'NumberTitle', 'off','name','Vertical orientation')
		clf
		subplot(2,1,1)
		p = semilogx(h,data(1:m/4,:),form);
		if islong, addlong(p,xlong,ylong(1:my/4,:)), end
		if linscale, set(gca,'xscale','linear'), end
		grid on
		title('In-phase component','fontsize',9)
		axis tight
		xlabel(xlab)
		ylabel(ylab1,'fontsize',11);	
		if legendavail == 1
			legend(legendCell,'location',pos)
		end
		subplot(2,1,2)
		p = semilogx(h,data(m/2+1:3*m/4,:),form);
		if islong, addlong(p,xlong,ylong(my/2+1:3*my/4,:)), end
		if linscale, set(gca,'xscale','linear'), end
		grid on
		if modeltype == 5
			title('Apparent conductivity','fontsize',9)
		else
			title('Quadrature component','fontsize',9)
		end
		axis tight
		xlabel(xlab)
		ylabel(ylab2,'fontsize',11);	
		
		figure(fig+1)
		set(gcf,'NumberTitle', 'off','name','Horizontal orientation')
		clf
		%title('Horizontal orientation')
		subplot(2,1,1)
		p = semilogx(h,data(m/4+1:m/2,:),form);
		if islong, addlong(p,xlong,ylong(my/4+1:my/2,:)), end
		if linscale, set(gca,'xscale','linear'), end
		grid on
		title('In-phase component','fontsize',9)
		axis tight
		xlabel(xlab)
		ylabel(ylab1,'fontsize',11);	
		if legendavail == 1
			legend(legendCell,'location',pos)
		end
		subplot(2,1,2)
		p = semilogx(h,data(3*m/4+1:m,:),form);
		if islong, addlong(p,xlong,ylong(3*my/4+1:my,:)), end
		if linscale, set(gca,'xscale','linear'), end
		grid on
		if modeltype == 5
			title('Apparent conductivity','fontsize',9)
		else
			title('Quadrature component','fontsize',9)
		end
		axis tight
		xlabel(xlab)
		ylabel(ylab2,'fontsize',11);	
	else
		figure(fig)
		set(gcf,'NumberTitle', 'off','name','Vertical orientation')
		clf
		p = semilogx(h,data(1:m/2,:),form);
		if islong, addlong(p,xlong,ylong(1:my/2,:)), end
		if linscale, set(gca,'xscale','linear'), end
		grid on
		%title('Vertical orientation','fontsize',11)
		axis tight
		xlabel(xlab)
		ylabel(ylab1,'fontsize',11);
		if legendavail ==1
			legend(legendCell,'location',pos)
		end
		
		figure(fig+1)
		set(gcf,'NumberTitle', 'off','name','Horizontal orientation')
		clf
		p = semilogx(h,data(m/2+1:m,:),form);
		if islong, addlong(p,xlong,ylong(my/2+1:my,:)), end
		if linscale, set(gca,'xscale','linear'), end
		grid on
		%title('Horizontal orientation','fontsize',11)
		axis tight
		xlabel(xlab)
		ylabel(ylab1,'fontsize',11);
		if legendavail == 1
			legend(legendCell,'location',pos)
		end
	end
elseif strcmpi(orientation(1:2),'vp')
	if complexdata
		figure(fig)
		set(gcf,'NumberTitle', 'off','name','Vertical orientation')
		clf
		subplot(2,1,1)
		p = semilogx(h,data(1:m/4,:),form);
		if islong, addlong(p,xlong,ylong(1:my/4,:)), end
		if linscale, set(gca,'xscale','linear'), end
		grid on
		title('In-phase component','fontsize',9)
		axis tight
		xlabel(xlab)
		ylabel(ylab1,'fontsize',11);	
		if legendavail == 1
			legend(legendCell,'location',pos)
		end
		subplot(2,1,2)
		p = semilogx(h,data(m/2+1:3*m/4,:),form);
		if islong, addlong(p,xlong,ylong(my/2+1:3*my/4,:)), end
		if linscale, set(gca,'xscale','linear'), end
		grid on
		if modeltype == 5
			title('Apparent conductivity','fontsize',9)
		else
			title('Quadrature component','fontsize',9)
		end
		axis tight
		xlabel(xlab)
		ylabel(ylab2,'fontsize',11);	
		
		figure(fig+1)
		set(gcf,'NumberTitle', 'off','name','Perpendicular orientation')
		clf
		%title('Horizontal orientation')
		subplot(2,1,1)
		p = semilogx(hp,data(m/4+1:m/2,:),form);
		if islong, addlong(p,xlongp,ylong(my/4+1:my/2,:)), end
		if linscale, set(gca,'xscale','linear'), end
		grid on
		title('In-phase component','fontsize',9)
		axis tight
		xlabel(xlab)
		ylabel(ylab1,'fontsize',11);	
		if legendavail == 1
			legend(legendCellp,'location',pos)
		end
		subplot(2,1,2)
		p = semilogx(hp,data(3*m/4+1:m,:),form);
		if islong, addlong(p,xlongp,ylong(3*my/4+1:my,:)), end
		if linscale, set(gca,'xscale','linear'), end
		grid on
		if modeltype == 5
			title('Apparent conductivity','fontsize',9)
		else
			title('Quadrature component','fontsize',9)
		end
		axis tight
		xlabel(xlab)
		ylabel(ylab2,'fontsize',11);	
	else
		figure(fig)
		set(gcf,'NumberTitle', 'off','name','Vertical orientation')
		clf
		p = semilogx(h,data(1:m/2,:),form);
		if islong, addlong(p,xlong,ylong(1:my/2,:)), end
		if linscale, set(gca,'xscale','linear'), end
		grid on
		%title('Vertical orientation','fontsize',11)
		axis tight
		xlabel(xlab)
		ylabel(ylab1,'fontsize',11);
		if legendavail ==1
			legend(legendCell,'location',pos)
		end
		
		figure(fig+1)
		set(gcf,'NumberTitle', 'off','name','Perpendicular orientation')
		clf
		p = semilogx(hp,data(m/2+1:m,:),form);
		if islong, addlong(p,xlongp,ylong(my/2+1:my,:)), end
		if linscale, set(gca,'xscale','linear'), end
		grid on
		%title('Horizontal orientation','fontsize',11)
		axis tight
		xlabel(xlab)
		ylabel(ylab1,'fontsize',11);
		if legendavail == 1
			legend(legendCellp,'location',pos)
		end
	end
else
	if complexdata
		if strcmpi(orientation(1:2),'ve')
			figure(fig)
			set(gcf,'NumberTitle', 'off','name','Vertical orientation')
		elseif strcmpi(orientation(1:2),'ho')
			figure(fig+1)
			set(gcf,'NumberTitle', 'off','name','Horizontal orientation')
		else
			figure(fig+1)
			set(gcf,'NumberTitle', 'off','name','Perpendicular orientation')
		end
		clf
		subplot(2,1,1)
		p = semilogx(h,data(1:m/2,:),form);
		if islong, addlong(p,xlong,ylong(1:my/2,:)), end
		if linscale, set(gca,'xscale','linear'), end
		grid on
		title('In-phase component','fontsize',9)
		axis tight
		xlabel(xlab)
		ylabel(ylab1,'fontsize',11);
		subplot(2,1,2)
		p = semilogx(h,data(m/2+1:m,:),form);
		if islong, addlong(p,xlong,ylong(my/2+1:my,:)), end
		if linscale, set(gca,'xscale','linear'), end
		if modeltype == 5
			title('Apparent conductivity','fontsize',9)
		else
			title('Quadrature component','fontsize',9)
		end
		axis tight
		xlabel(xlab)
		ylabel(ylab2,'fontsize',11);
		grid on
		if legendavail == 1
			legend(legendCell,'location',pos)
		end
	else
		if strcmpi(orientation(1:2),'ve')
			figure(fig)
			set(gcf,'NumberTitle', 'off','name','Vertical orientation')
		elseif strcmpi(orientation(1:2),'ho')
			figure(fig+1)
			set(gcf,'NumberTitle', 'off','name','Horizontal orientation')
		else
			figure(fig+1)
			set(gcf,'NumberTitle', 'off','name','Perpendicular orientation')
		end
		%set(gcf,'name','')
		clf
		p = semilogx(h,data,form);
		if islong, addlong(p,xlong,ylong), end
		if linscale, set(gca,'xscale','linear'), end
		grid on
		if legendavail == 1
			legend(legendCell,'location',pos)
		end
		if strcmpi(orientation(1:2),'ve')
			set(gcf,'name','Vertical orientation')
			%title('Vertical orientation')
			axis tight
			xlabel('Height (m)')
			xlabel(xlab)
			ylabel(ylab1,'fontsize',11);
		elseif strcmpi(orientation(1:2),'ho')
			set(gcf,'name','Horizontal orientation')
			%title('Horizontal orientation')
			axis tight
			xlabel('Height (m)')
			xlabel(xlab)
			ylabel(ylab1,'fontsize',11);
		else
			set(gcf,'name','Perpendicular orientation')
			%title('Horizontal orientation')
			axis tight
			xlabel('Height (m)')
			xlabel(xlab)
			ylabel(ylab1,'fontsize',11);
		end
	end	
end
end

function addlong(p,xl,yl)
hold on
p1 = semilogx(xl,yl);
hold off
for i = 1:length(p)
	set(p1(i),'color',get(p(i),'color'))
end
end
